// generated by netcdf_constants.awk
  netcdf_constants["NC_NAT"] = octave_value(NC_NAT);
  netcdf_constants["NC_BYTE"] = octave_value(NC_BYTE);
  netcdf_constants["NC_CHAR"] = octave_value(NC_CHAR);
  netcdf_constants["NC_SHORT"] = octave_value(NC_SHORT);
  netcdf_constants["NC_INT"] = octave_value(NC_INT);
  netcdf_constants["NC_LONG"] = octave_value(NC_LONG);
  netcdf_constants["NC_FLOAT"] = octave_value(NC_FLOAT);
  netcdf_constants["NC_DOUBLE"] = octave_value(NC_DOUBLE);
  netcdf_constants["NC_UBYTE"] = octave_value(NC_UBYTE);
  netcdf_constants["NC_USHORT"] = octave_value(NC_USHORT);
  netcdf_constants["NC_UINT"] = octave_value(NC_UINT);
  netcdf_constants["NC_INT64"] = octave_value(NC_INT64);
  netcdf_constants["NC_UINT64"] = octave_value(NC_UINT64);
  netcdf_constants["NC_STRING"] = octave_value(NC_STRING);
  netcdf_constants["NC_FILL_BYTE"] = octave_value(octave_int8(NC_FILL_BYTE));
  netcdf_constants["NC_FILL_CHAR"] = octave_value((char)NC_FILL_CHAR);
  netcdf_constants["NC_FILL_SHORT"] = octave_value(octave_int16(NC_FILL_SHORT));
  netcdf_constants["NC_FILL_INT"] = octave_value(octave_int32(NC_FILL_INT));
  netcdf_constants["NC_FILL_FLOAT"] = octave_value((float)NC_FILL_FLOAT);
  netcdf_constants["NC_FILL_DOUBLE"] = octave_value(NC_FILL_DOUBLE);
  netcdf_constants["NC_FILL_UBYTE"] = octave_value(octave_uint8(NC_FILL_UBYTE));
  netcdf_constants["NC_FILL_USHORT"] = octave_value(octave_uint16(NC_FILL_USHORT));
  netcdf_constants["NC_FILL_UINT"] = octave_value(octave_uint32(NC_FILL_UINT));
  netcdf_constants["NC_FILL_INT64"] = octave_value(octave_int32(NC_FILL_INT64));
  netcdf_constants["NC_FILL_UINT64"] = octave_value(octave_uint32(NC_FILL_UINT64));
  netcdf_constants["NC_FILL_STRING"] = octave_value(std::string(NC_FILL_STRING));
  netcdf_constants["NC_MAX_BYTE"] = octave_value(octave_int8(NC_MAX_BYTE));
  netcdf_constants["NC_MIN_BYTE"] = octave_value(octave_int8(NC_MIN_BYTE));
  netcdf_constants["NC_MAX_CHAR"] = octave_value((char)NC_MAX_CHAR);
  netcdf_constants["NC_MAX_SHORT"] = octave_value(octave_int16(NC_MAX_SHORT));
  netcdf_constants["NC_MIN_SHORT"] = octave_value(octave_int16(NC_MIN_SHORT));
  netcdf_constants["NC_MAX_INT"] = octave_value(octave_int32(NC_MAX_INT));
  netcdf_constants["NC_MIN_INT"] = octave_value(octave_int32(NC_MIN_INT));
  netcdf_constants["NC_MAX_FLOAT"] = octave_value((float)NC_MAX_FLOAT);
  netcdf_constants["NC_MIN_FLOAT"] = octave_value((float)NC_MIN_FLOAT);
  netcdf_constants["NC_MAX_DOUBLE"] = octave_value(NC_MAX_DOUBLE);
  netcdf_constants["NC_MIN_DOUBLE"] = octave_value(NC_MIN_DOUBLE);
  netcdf_constants["NC_MAX_UBYTE"] = octave_value(octave_uint8(NC_MAX_UBYTE));
  netcdf_constants["NC_MAX_USHORT"] = octave_value(octave_uint16(NC_MAX_USHORT));
  netcdf_constants["NC_MAX_UINT"] = octave_value(octave_uint32(NC_MAX_UINT));
  netcdf_constants["NC_MAX_INT64"] = octave_value(octave_int32(NC_MAX_INT64));
  netcdf_constants["NC_MIN_INT64"] = octave_value(octave_int32(NC_MIN_INT64));
  netcdf_constants["NC_MAX_UINT64"] = octave_value(octave_uint32(NC_MAX_UINT64));
  netcdf_constants["NC_FILL"] = octave_value(NC_FILL);
  netcdf_constants["NC_NOFILL"] = octave_value(NC_NOFILL);
  netcdf_constants["NC_NOWRITE"] = octave_value(NC_NOWRITE);
  netcdf_constants["NC_WRITE"] = octave_value(NC_WRITE);
  netcdf_constants["NC_CLOBBER"] = octave_value(NC_CLOBBER);
  netcdf_constants["NC_NOCLOBBER"] = octave_value(NC_NOCLOBBER);
  netcdf_constants["NC_64BIT_OFFSET"] = octave_value(NC_64BIT_OFFSET);
  netcdf_constants["NC_NETCDF4"] = octave_value(NC_NETCDF4);
  netcdf_constants["NC_CLASSIC_MODEL"] = octave_value(NC_CLASSIC_MODEL);
  netcdf_constants["NC_SHARE"] = octave_value(NC_SHARE);
  netcdf_constants["NC_MPIIO"] = octave_value(NC_MPIIO);
  netcdf_constants["NC_MPIPOSIX"] = octave_value(NC_MPIPOSIX);
  netcdf_constants["NC_PNETCDF"] = octave_value(NC_PNETCDF);
  netcdf_constants["NC_LOCK"] = octave_value(NC_LOCK);
  netcdf_constants["NC_FORMAT_CLASSIC"] = octave_value(NC_FORMAT_CLASSIC);
  netcdf_constants["NC_FORMAT_64BIT"] = octave_value(NC_FORMAT_64BIT);
  netcdf_constants["NC_FORMAT_NETCDF4"] = octave_value(NC_FORMAT_NETCDF4);
  netcdf_constants["NC_FORMAT_NETCDF4_CLASSIC"] = octave_value(NC_FORMAT_NETCDF4_CLASSIC);
  netcdf_constants["NC_SIZEHINT_DEFAULT"] = octave_value(NC_SIZEHINT_DEFAULT);
  netcdf_constants["NC_ALIGN_CHUNK"] = octave_value(NC_ALIGN_CHUNK);
  netcdf_constants["NC_UNLIMITED"] = octave_value(NC_UNLIMITED);
  netcdf_constants["NC_GLOBAL"] = octave_value(NC_GLOBAL);
  netcdf_constants["NC_MAX_DIMS"] = octave_value(NC_MAX_DIMS);
  netcdf_constants["NC_MAX_ATTRS"] = octave_value(NC_MAX_ATTRS);
  netcdf_constants["NC_MAX_VARS"] = octave_value(NC_MAX_VARS);
  netcdf_constants["NC_MAX_NAME"] = octave_value(NC_MAX_NAME);
  netcdf_constants["NC_MAX_VAR_DIMS"] = octave_value(NC_MAX_VAR_DIMS);
  netcdf_constants["NC_ENDIAN_NATIVE"] = octave_value(NC_ENDIAN_NATIVE);
  netcdf_constants["NC_ENDIAN_LITTLE"] = octave_value(NC_ENDIAN_LITTLE);
  netcdf_constants["NC_ENDIAN_BIG"] = octave_value(NC_ENDIAN_BIG);
  netcdf_constants["NC_CHUNKED"] = octave_value(NC_CHUNKED);
  netcdf_constants["NC_CONTIGUOUS"] = octave_value(NC_CONTIGUOUS);
  netcdf_constants["NC_NOCHECKSUM"] = octave_value(NC_NOCHECKSUM);
  netcdf_constants["NC_FLETCHER32"] = octave_value(NC_FLETCHER32);
  netcdf_constants["NC_NOSHUFFLE"] = octave_value(NC_NOSHUFFLE);
  netcdf_constants["NC_SHUFFLE"] = octave_value(NC_SHUFFLE);
  netcdf_constants["NC_NOERR"] = octave_value(NC_NOERR);
  netcdf_constants["NC_EBADID"] = octave_value(NC_EBADID);
  netcdf_constants["NC_ENFILE"] = octave_value(NC_ENFILE);
  netcdf_constants["NC_EEXIST"] = octave_value(NC_EEXIST);
  netcdf_constants["NC_EINVAL"] = octave_value(NC_EINVAL);
  netcdf_constants["NC_EPERM"] = octave_value(NC_EPERM);
  netcdf_constants["NC_ENOTINDEFINE"] = octave_value(NC_ENOTINDEFINE);
  netcdf_constants["NC_EINDEFINE"] = octave_value(NC_EINDEFINE);
  netcdf_constants["NC_EINVALCOORDS"] = octave_value(NC_EINVALCOORDS);
  netcdf_constants["NC_EMAXDIMS"] = octave_value(NC_EMAXDIMS);
  netcdf_constants["NC_ENAMEINUSE"] = octave_value(NC_ENAMEINUSE);
  netcdf_constants["NC_ENOTATT"] = octave_value(NC_ENOTATT);
  netcdf_constants["NC_EMAXATTS"] = octave_value(NC_EMAXATTS);
  netcdf_constants["NC_EBADTYPE"] = octave_value(NC_EBADTYPE);
  netcdf_constants["NC_EBADDIM"] = octave_value(NC_EBADDIM);
  netcdf_constants["NC_EUNLIMPOS"] = octave_value(NC_EUNLIMPOS);
  netcdf_constants["NC_EMAXVARS"] = octave_value(NC_EMAXVARS);
  netcdf_constants["NC_ENOTVAR"] = octave_value(NC_ENOTVAR);
  netcdf_constants["NC_EGLOBAL"] = octave_value(NC_EGLOBAL);
  netcdf_constants["NC_ENOTNC"] = octave_value(NC_ENOTNC);
  netcdf_constants["NC_ESTS"] = octave_value(NC_ESTS);
  netcdf_constants["NC_EMAXNAME"] = octave_value(NC_EMAXNAME);
  netcdf_constants["NC_EUNLIMIT"] = octave_value(NC_EUNLIMIT);
  netcdf_constants["NC_ENORECVARS"] = octave_value(NC_ENORECVARS);
  netcdf_constants["NC_ECHAR"] = octave_value(NC_ECHAR);
  netcdf_constants["NC_EEDGE"] = octave_value(NC_EEDGE);
  netcdf_constants["NC_ESTRIDE"] = octave_value(NC_ESTRIDE);
  netcdf_constants["NC_EBADNAME"] = octave_value(NC_EBADNAME);
  netcdf_constants["NC_ERANGE"] = octave_value(NC_ERANGE);
  netcdf_constants["NC_ENOMEM"] = octave_value(NC_ENOMEM);
  netcdf_constants["NC_EVARSIZE"] = octave_value(NC_EVARSIZE);
  netcdf_constants["NC_EDIMSIZE"] = octave_value(NC_EDIMSIZE);
  netcdf_constants["NC_ETRUNC"] = octave_value(NC_ETRUNC);
  netcdf_constants["NC_EAXISTYPE"] = octave_value(NC_EAXISTYPE);
  netcdf_constants["NC_EDAP"] = octave_value(NC_EDAP);
  netcdf_constants["NC_ECURL"] = octave_value(NC_ECURL);
  netcdf_constants["NC_EIO"] = octave_value(NC_EIO);
  netcdf_constants["NC_ENODATA"] = octave_value(NC_ENODATA);
  netcdf_constants["NC_EDAPSVC"] = octave_value(NC_EDAPSVC);
  netcdf_constants["NC_EDAS"] = octave_value(NC_EDAS);
  netcdf_constants["NC_EDDS"] = octave_value(NC_EDDS);
  netcdf_constants["NC_EDATADDS"] = octave_value(NC_EDATADDS);
  netcdf_constants["NC_EDAPURL"] = octave_value(NC_EDAPURL);
  netcdf_constants["NC_EDAPCONSTRAINT"] = octave_value(NC_EDAPCONSTRAINT);
  netcdf_constants["NC_EHDFERR"] = octave_value(NC_EHDFERR);
  netcdf_constants["NC_ECANTREAD"] = octave_value(NC_ECANTREAD);
  netcdf_constants["NC_ECANTWRITE"] = octave_value(NC_ECANTWRITE);
  netcdf_constants["NC_ECANTCREATE"] = octave_value(NC_ECANTCREATE);
  netcdf_constants["NC_EFILEMETA"] = octave_value(NC_EFILEMETA);
  netcdf_constants["NC_EDIMMETA"] = octave_value(NC_EDIMMETA);
  netcdf_constants["NC_EATTMETA"] = octave_value(NC_EATTMETA);
  netcdf_constants["NC_EVARMETA"] = octave_value(NC_EVARMETA);
  netcdf_constants["NC_ENOCOMPOUND"] = octave_value(NC_ENOCOMPOUND);
  netcdf_constants["NC_EATTEXISTS"] = octave_value(NC_EATTEXISTS);
  netcdf_constants["NC_ENOTNC4"] = octave_value(NC_ENOTNC4);
  netcdf_constants["NC_ESTRICTNC3"] = octave_value(NC_ESTRICTNC3);
  netcdf_constants["NC_ENOTNC3"] = octave_value(NC_ENOTNC3);
  netcdf_constants["NC_ENOPAR"] = octave_value(NC_ENOPAR);
  netcdf_constants["NC_EPARINIT"] = octave_value(NC_EPARINIT);
  netcdf_constants["NC_EBADGRPID"] = octave_value(NC_EBADGRPID);
  netcdf_constants["NC_EBADTYPID"] = octave_value(NC_EBADTYPID);
  netcdf_constants["NC_ETYPDEFINED"] = octave_value(NC_ETYPDEFINED);
  netcdf_constants["NC_EBADFIELD"] = octave_value(NC_EBADFIELD);
  netcdf_constants["NC_EBADCLASS"] = octave_value(NC_EBADCLASS);
  netcdf_constants["NC_EMAPTYPE"] = octave_value(NC_EMAPTYPE);
  netcdf_constants["NC_ELATEFILL"] = octave_value(NC_ELATEFILL);
  netcdf_constants["NC_ELATEDEF"] = octave_value(NC_ELATEDEF);
  netcdf_constants["NC_EDIMSCALE"] = octave_value(NC_EDIMSCALE);
  netcdf_constants["NC_ENOGRP"] = octave_value(NC_ENOGRP);
  netcdf_constants["NC_ESTORAGE"] = octave_value(NC_ESTORAGE);
  netcdf_constants["NC_EBADCHUNK"] = octave_value(NC_EBADCHUNK);
  netcdf_constants["NC_ENOTBUILT"] = octave_value(NC_ENOTBUILT);
  netcdf_constants["NC_HAVE_NEW_CHUNKING_API"] = octave_value(NC_HAVE_NEW_CHUNKING_API);
  netcdf_constants["NC_ENTOOL"] = octave_value(NC_ENTOOL);
  netcdf_constants["NC_EXDR"] = octave_value(NC_EXDR);
  netcdf_constants["NC_SYSERR"] = octave_value(NC_SYSERR);
  netcdf_constants["NC_FATAL"] = octave_value(NC_FATAL);
  netcdf_constants["NC_VERBOSE"] = octave_value(NC_VERBOSE);
